@@ -1,11 +1,12 @@
 from base64 import standard_b64encode
+from os import linesep
 from textwrap import wrap
 
-__CRC24_INIT__ = 0x0b704ce
-__CRC24_POLY__ = 0x1864cfb
+__CRC24_INIT = 0x0b704ce
+__CRC24_POLY = 0x1864cfb
 
 def __crc24(data: bytes) -> bytes:
-    crc = __CRC24_INIT__
+    crc = __CRC24_INIT
 
     for b in data:
       crc ^= b << 16
@@ -13,7 +14,7 @@ def __crc24(data: bytes) -> bytes:
       for i in range(8):
         crc <<= 1
         if crc & 0x1000000:
-          crc ^= __CRC24_POLY__
+          crc ^= __CRC24_POLY
 
     crc = crc & 0xFFFFFF
     return crc.to_bytes(3, 'big')
@@ -31,4 +32,4 @@ def armour(header: str, payload: bytes) -> str:
   wrapped.append('-----END PGP %s-----' % (header))
   wrapped.append('') # final newline!
 
-  return ('\n'.join(wrapped)).encode('utf-8')
+  return (linesep.join(wrapped)).encode('utf-8')
